---
title: 글로벌_해외결제 입점가능 결제대행사 찾기
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
tags:
  - 해외결제
searchTags:
  - '쇼피파이로 구축 '
  - 쇼피파이를 통한 국내결제
  - 자체구축
  - 쇼피파이
  - 글로벌 결제
  - 입점가능 PG사 찾기
  - 해외결제 입점가능
  - 해외결제
  - 글로벌
datetime: 2025-02-24T02:21:40.873Z
---

<Callout content="고객사 비지니스 모델에 따라 입점 가능한 PG사와 결제수단이 다릅니다. 
아래의 기준에 따라 입점 가능한 결제대행사(PG사)와 결제수단을 확정하고 전자결제 신청을 진행 해 주세요." />

## **쇼피파이로 구축된 경우**

- 쇼피파이는 정기결제를 지원하지 않습니다.
- 쇼피파이의 경우 글로벌 포트원 콘솔 계정 생성이 필요합니다.
- 쇼피파이 플러그인은 국내PG를 지원하며 지원PG 및 결제수단은 개발자 문서를 참고해 주세요.
- **쇼피파이는 Sass 이용계약서 작성 이 후 이용이 가능합니다. (쇼피파이 플러그인 이용요금 발생**)
  - 월거래금액의 0.5% ( <Highlight text="0.15%는 포트원 이용요금" />, 0.35%는 쇼피파이에 포트원이 대납하는 요금)
  - <Highlight text="월거래금액 * 0.15%가 $500이 되지 않는 경우 최소 이용요금으로 $500 청구 됩니다." />
  - 월초에 청구되면 월말까지 납부하여야 합니다.
  - 환율은 월말일 날짜 기준으로 계산하여 KRW로 환산된 금액이 청구 됩니다.

### **페이레터**

- 신용카드만 지원
- 승인통화 : KRW, USD, JPY
- 정산통화 :  KRW, USD
- 수수료:
  - 객단가 $50 이상: 4.00% + **0.5%(포트원 이용요금**)
  - 객단가 $50 미만: 5.60% + **0.5%(포트원 이용요금**)
- 정산주기
  - 해외카드(Visa, Master, JCB, Amex, UnionPay) : 매주 목요일 정산(익익주 전 일요일\~토요일 거래)
  - 정산시 , 환율기준 : 정산 전 일 국민은행 10회차 고시 환율(전신환 매입율) 적용
  - 롤링 리저브 : 10%, 180일(일반 PG사의 보증보험의 개념으로, 정산금액의 10%를 180일동안 가지고 있다가 이후에 정산해주는 개념입니다)
- 사전심사항목
  - 상호 :
  - 사업자번호 :
  - 서비스 URL :
  - 해외 구매자 대상 서비스 URL :
  - 제공 서비스 유형(상세설명필요) :
  - 사용 희망 결제수단 :
  - 결제 객단가 :
  - 승인통화/정산통화 :
  - 월/연간 예상 거래액 :
  - 결제방식(일반결제, 정기결제) :
  - 계약 담당자 정보 (성함, 직함, 전화번호, 이메일) :
  - 쇼피파이 호스팅 사용 여부 :

`참고: 페이레터는 사전심사를 통해 입점 가능 여부를 파악해야 합니다.`

### **KG 이니시스 일본결제**

- 신용카드, 편의점결제, 간편결제 지원
- 일반결제만 지원
- 승인통화 : JPY
- 정산통화 : KRW
- \[실물상품]\[비실물 상품]
  - 신용카드 VISA/MASTER/JCB/AMEX/DINERS: 3.9% + **0.5%(포트원 이용요금**)
  - 편의점 결제 7Eleven/LAWSON/FamilyMart/MINISTOP/SEICO MART: 3.7% + **0.5%(포트원 이용요금**)
  - 간편결제 RPay/AmazonPay/D barai/AU Pay/ MerPay: 6.7% + **0.5% (포트원 이용요금)**
  - 신용카드 VISA/MASTER/JCB/AMEX/DINERS: 6.5% + **0.5%(포트원 이용요금)**
  - 편의점 결제 7Eleven/LAWSON/FamilyMart/MINISTOP/SEICO MART: 3.7% + **0.5%(포트원 이용요금)**
  - 간편결제 RPay/AmazonPay/D barai/AU Pay/ MerPay: 13.7% + **0.5% (포트원 이용요금)**
- 편의점 결제 안내
  - 편의점 결제의 경우, 최저 수수료 : 180엔
  - 편의점 결제의 경우, PG사에서 환불을 진행하고 있지 않아 고객사에서 직접 환불 진행 해야 하는 점 참고 부탁드립니다.
- 이니시스 심사비 및 연관리비(VAT별도)
  - 초기등록비(심사비) : 150,000원 (VAT별도)
  - 연관리비 : 600,000원 (VAT별도)

**`참고: 이니시스 일본과 관련한 자세한 내용은 해당 가이드를 통해 확인해주세요.`**

<Callout title="KG이니시스 일본결제 서비스 이용안내 보러가기 ↗" />

## **자체구축인 경우**

### **엑심베이**

- 신용카드, Alipay , Wechat, eContext 지원
- 승인통화 : 미국, 일본, 유럽, 영국, 홍콩, 대만, 싱가포르, 캐나다, 호주, 태국, 러시아, 마카오, 베트남, 브라질, 필리핀, 몽골, 터키, 뉴질랜드, 아랍에미레이트, 말레이시아, 카자흐스탄, 노르웨이, 사우디아라비아
- 정산통화 : KRW, USD
- 정산주기 : 계약이후 정확한 정산주기가 설정되며, 보통 일주일간의 거래를 3주후에 정산하는 방식으로 진행됩니다.
- 수수료:
  - VISA/MASTER/JCB/Amex : 4.50% (해외 발행 글로벌 카드)
  - Alipay : 2.90%
  - Wechat (PC) : 2.80%
  - eContext (일본) : 4.50%

### **페이팔**

- 일반결제, 정기결제 지원
- 선승인 후심사 방식으로 바로 결제이용이 가능합니다.
- 정산은 페이팔 정산계좌에 쌓인 금액을 인출하는 방식이며 인출 시점에 환전수수료 발생합니다.
- 수수료는 페이팔 상세 가이드 참고

<Callout content="필요하신 결제수단, 승인통화, 정산통화, 결제방식(일반,정기)에 따라 이용가능한 PG사를 고르셨다면
테스트 결제연동을 하신 이후 전자결제신청을 해주세요." icon="💡" />

<Callout title="페이팔 해외결제 서비스이용안내 보러가기 ↗" />

## **Shopify를 통해 국내 결제를 연동 하고 싶은 경우**

- 쇼피파이는 정기결제를 지원하지 않습니다.
- 쇼피파이의 경우 글로벌 포트원 콘솔 계정 생성이 필요합니다.
- 쇼피파이 플러그인은 국내PG를 지원하며 지원PG 및 결제수단은 개발자 문서를 참고해 주세요.
- 쇼피파이는 Sass 이용계약서 작성 이 후 이용이 가능합니다. (쇼피파이 플러그인 이용요금 발생)
  - 월거래금액의 0.5%(<Highlight text="0.15%는 포트원 이용요금" />, 0.35%는 쇼피파이에 포트원이 대납하는 요금)
  - 월거래금액 \* 0.15%가 $500이 되지 않는 경우 최소 이용요금으로 $500 청구 됩니다.
  - 월초에 청구되면 월말까지 납부하여야 합니다.
  - 환율은 월말일 날짜 기준으로 계산하여 KRW로 환산된 금액이 청구 됩니다.

**`참고 : Shopify 플러그인 에서 희망하는 국내 PG 선택 후, 전자결제 신청을 해주시길 바랍니다.`**

<Callout title="Shopify 플러그인 이용방법 보러가기 ↗" />

<Callout title="전자결제 신청방법 보러가기 ↗" />

<Highlight />
